Cursor

Enum Cursor 

pub enum Cursor {
Show 39 variants Default = 0, Help = 1, Pointer = 2, Progress = 3, Wait = 4, Cell = 5, Crosshair = 6, Text = 7, VerticalText = 8, Alias = 9, Copy = 10, Move = 11, NotAllowed = 12, Grab = 13, Grabbing = 14, ColResize = 15, RowResize = 16, EastWestResize = 17, NorthSouthResize = 18, NorthEastSouthWestResize = 19, NorthWestSouthEastResize = 20, ZoomIn = 21, ZoomOut = 22, UpArrow = 23, Pin = 24, Person = 25, Pen = 26, Cd = 27, PanMiddle = 28, PanMiddleHorizontal = 29, PanMiddleVertical = 30, PanEast = 31, PanNorth = 32, PanNorthEast = 33, PanNorthWest = 34, PanSouth = 35, PanSouthEast = 36, PanSouthWest = 37, PanWest = 38,
}
Describes a possible cursor type.

Variants



Default = 0

The platform default cursor. Typically an arrow.



Help = 1

A cursor indicating that helpful information is available.



Pointer = 2

A cursor indicating that something is clickable, typically a pointing hand.



Progress = 3

The program is busy at background but can still interactable. Typically an arrow with a loading indicator.



Wait = 4

The program is busy and cannot interact. Typically an hourglass or spinning circle.



Cell = 5

Table cell selection cursor



Crosshair = 6

Cross cursor typically used for precision selection, e.g. in graphics applications.



Text = 7

A horizontal ibeam cursor for indicating text insertion, typically used for text.



VerticalText = 8

A vertical ibeam cursor for indicating text insertion, typically used for vertical text.



Alias = 9

Cursor for indicating something can be aliased or shortcuted.



Copy = 10

Cursor for indicating something can be copied.



Move = 11

Crossed arrows for moving something.



NotAllowed = 12

Not allowed cursor (typically a circle with a line through it)



Grab = 13

Hand cursor for something can be grabbed. e.g. draggable item



Grabbing = 14

Hand grabbing cursor.



ColResize = 15

Cursor for horizontal resizing (e.g. left-right arrows with a bar in the middle)



RowResize = 16

Cursor for vertical resizing (e.g. up-down arrows with a bar in the middle)



EastWestResize = 17

Cursor for horizontal resizing (e.g. left-right arrows)



NorthSouthResize = 18

Cursor for vertical resizing (e.g. up-down arrows)



NorthEastSouthWestResize = 19

Cursor for diagonal resizing (e.g. top-left to bottom-right arrows)



NorthWestSouthEastResize = 20

Cursor for diagonal resizing (e.g. top-right to bottom-left arrows)



ZoomIn = 21

Cursor for something can be zoomed in. Typically a magnifying glass with a plus sign.



ZoomOut = 22

Cursor for something can be zoomed out. Typically a magnifying glass with a minus sign.



UpArrow = 23

Windows specific up arrow cursor matching IDC_UPARROW



Pin = 24

Windows specific pin cursor matching IDC_PIN



Person = 25

Windows specific person cursor matching IDC_PERSON



Pen = 26

Windows specific pen cursor matching 32631



Cd = 27

Windows specific cd cursor matching 32663



PanMiddle = 28

Panning cursors with crossed arrows



PanMiddleHorizontal = 29

Panning cursors with horizontal arrows



PanMiddleVertical = 30

Panning cursors with vertical arrows



PanEast = 31

Panning cursors with a arrow to right.



PanNorth = 32

Panning cursors with a arrow to top.



PanNorthEast = 33

Panning cursors with arrows to top and right.



PanNorthWest = 34

Panning cursors with arrows to top and left.



PanSouth = 35

Panning cursors with a arrow to down.



PanSouthEast = 36

Panning cursors with arrows to down and right.



PanSouthWest = 37

Panning cursors with arrows to down and left.



PanWest = 38

Panning cursors with a arrow to left.