OverlayEvent

Enum OverlayEvent 

pub enum OverlayEvent {
    Window {
        id: u32,
        event: WindowEvent,
    },
    Surface {
        id: u64,
        event: SurfaceEvent,
    },
    InputBlockingEnded,
    Tracing(TracingEvent),
}
Describe a overlay event.

Variants



Window

Events related to a specific window.

Fields

id: u32


Surface

Events related to a specific surface.

Fields

id: u64


InputBlockingEnded

Input blocking is turned off or interrupted by the user or system.

The user may turn off input blocking at any time, for example, by pressing Alt+F4 on Windows.



Tracing(TracingEvent)

A tracing from overlay system.