pub enum WindowRequest {
SetPosition(SetPosition),
SetAnchor(SetAnchor),
SetMargin(SetMargin),
ListenInput(ListenInput),
BlockInput(BlockInput),
SetBlockingCursor(SetBlockingCursor),
UpdateSharedHandle(UpdateSharedHandle),
}Expand description
Describes a request to a specific window.
Variants
SetPosition(SetPosition)
Set overlay surface position.
SetAnchor(SetAnchor)
Set overlay surface positioning anchor.
SetMargin(SetMargin)
Set overlay surface margin.
ListenInput(ListenInput)
Change whether to listen input events.
BlockInput(BlockInput)
Whether to block input events from reaching window and listen all input events.
SetBlockingCursor(SetBlockingCursor)
Set cursor of a window when being input blocked.
Set overlay surface shared handle.