BlockInput

Struct BlockInput 

pub struct BlockInput {
    pub block: bool,
}
Block input events from reaching window and listen all input events

Fields

block: bool

Whether to block input events from reaching to window.