SetAnchor

Struct SetAnchor 

pub struct SetAnchor {
    pub x: PercentLength,
    pub y: PercentLength,
}
Set overlay surface positioning anchor relative to the top-left of the overlay surface.

Fields

x: PercentLength

Anchor of X axis as percent relative to the window’s width.

y: PercentLength

Anchor of Y axis as percent relative to the window’s height.