SetMargin

Struct SetMargin 

pub struct SetMargin {
    pub top: PercentLength,
    pub right: PercentLength,
    pub bottom: PercentLength,
    pub left: PercentLength,
}
Set overlay surface margin relative to the overlay surface’s size.

Fields

top: PercentLength

Margin of top side as percent or absolute length relative to the overlay surface’s height.

right: PercentLength

Margin of right side as percent or absolute length relative to the overlay surface’s width.

bottom: PercentLength

Margin of bottom side as percent or absolute length relative to the overlay surface’s height.

left: PercentLength

Margin of left side as percent or absolute length relative to the overlay surface’s width.

Implementations

Source

impl SetMargin

pub const fn xy(x: PercentLength, y: PercentLength) -> Self

Utility function to set same margin for axis.