SetPosition

Struct SetPosition 

pub struct SetPosition {
    pub x: PercentLength,
    pub y: PercentLength,
}
Set overlay surface position relative to the window client area.

Fields

x: PercentLength

X position of percent or absolute length relative to the window’s width.

y: PercentLength

Y position of percent or absolute length relative to the window’s height.