pub enum PercentLength {
Percent(f32),
Length(f32),
}Expand description
A length that can be specified as either a percentage of a container size or an absolute length.
Variants
Percent(f32)
A percentage length relative to a base size.
For example, 0.5 is 50% of the base size.
Length(f32)
An absolute length. Usually in pixels.
For example, 100.0 is 100 pixels.
Implementations
Sourceimpl PercentLength
impl PercentLength