pub struct BlockInput {
pub block: bool,
}Expand description
Block input events from reaching window and listen all input events
Fields
block: boolWhether to block input events from reaching to window.