pub struct SetAnchor {
pub x: PercentLength,
pub y: PercentLength,
}Expand description
Set overlay surface positioning anchor relative to the top-left of the overlay surface.
Fields
x: PercentLengthAnchor of X axis as percent relative to the window’s width.
y: PercentLengthAnchor of Y axis as percent relative to the window’s height.