pub struct SetMargin {
pub top: PercentLength,
pub right: PercentLength,
pub bottom: PercentLength,
pub left: PercentLength,
}Expand description
Set overlay surface margin relative to the overlay surface’s size.
Fields
top: PercentLengthMargin of top side as percent or absolute length relative to the overlay surface’s height.
right: PercentLengthMargin of right side as percent or absolute length relative to the overlay surface’s width.
bottom: PercentLengthMargin of bottom side as percent or absolute length relative to the overlay surface’s height.
left: PercentLengthMargin of left side as percent or absolute length relative to the overlay surface’s width.
Implementations
Sourceimpl SetMargin
impl SetMargin
Sourcepub const fn xy(x: PercentLength, y: PercentLength) -> Self
pub const fn xy(x: PercentLength, y: PercentLength) -> Self
Utility function to set same margin for axis.