pub struct SetPosition {
pub x: PercentLength,
pub y: PercentLength,
}Expand description
Set overlay surface position relative to the window client area.
Fields
x: PercentLengthX position of percent or absolute length relative to the window’s width.
y: PercentLengthY position of percent or absolute length relative to the window’s height.